% Example for creating a netcdf file
% in Matlab and Octave

% create some variables to store them in a netcdf file

latitude = -90:1:90;
longitude = -179:1:180;
[y,x] = meshgrid(pi/180 * latitude,pi/180 * longitude);
temp = cos(2*x) .* cos(y);

%---------------------------------------%
%                                       %
% write data to a netcdf file           %
%                                       %
%---------------------------------------%

% create netcdf file called example.nc
% 'c' = 'clobber': overwrite if exists

nc = netcdf('example.nc','c');

% define the dimension longitude and latitude of size
% 360 and 181 respectively.

nc('longitude') = 360;
nc('latitude') = 181;

% coordinate variable longitude

% create a variable longitude of type double with 
% 360 elements (dimension longitude).
nc{'longitude'} = ncdouble('longitude');              

% store the octave variable longitude in the netcdf file
nc{'longitude'}(:) = longitude;                       

% define a string attribute of the variable longitude
nc{'longitude'}.units = 'degree West';                

% coordinate variable latitude

nc{'latitude'} = ncdouble('latitude');;                  
nc{'latitude'}(:) = latitude;                         
nc{'latitude'}.units = 'degree North';                

% define variable temp

% create a variable temp of type double of the size 360x181 
% (dimension latitude, longitude).    

nc{'temp'} = ncdouble('latitude','longitude');        

% store the octave variable temp in the netcdf file
nc{'temp'}(:) = temp';

% define a string attribute of the variable
nc{'temp'}.units = 'degree Celsius';                  

% define a vector of doubles attribute of the variable
nc{'temp'}.valid_range = [-10 40];                    

% define a global string attribute
nc.history = 'netcdf file created by example_netcdf.m in octave';

% close netcdf file and all changes are written to disk
close(nc)


disp(['example.nc file created. You might now inspect this file"']);
disp(['with the shell command "ncdump -h example.nc"']);

